==> hinemos-2.1.0_src.tar.gz: hinemos-2.1.0_src/PerformanceService/src/com/clustercontrol/performanceMGR/jmx/PerformanceService.java <==
/*
                                                                                                
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.
 
*/

package com.clustercontrol.performanceMGR.jmx;

import javax.naming.CompositeName;
import javax.naming.Context;
import javax.naming.InitialContext;
import javax.naming.Name;
import javax.naming.NamingException;

import org.jboss.naming.NonSerializableFactory;
import org.jboss.system.ServiceMBeanSupport;

/**
 * @jmx.mbean
 *     name="user:service=PerformanceService,name=PerformanceService"
 *     description="PerformanceService MBean"
 *     extends="org.jboss.system.ServiceMBean"
 * 
 * @jboss.service servicefile="snmppoller"
 */
public class PerformanceService extends ServiceMBeanSupport implements PerformanceServiceMBean{
	private String jndiName = "PerformanceService";  // JNDIϿݤ̾
	
	private PerformanceRestartManager manager;
	
	public PerformanceService(){
	}
	
    /**
     * @jmx.managed-attribute
     * @return
     */
    public String getJndiName() {
        return jndiName;
    }
    
    /**
     * @jmx.managed-attribute
     * 
     * @param jndiName
     * @throws NamingException 
     * @throws NamingException
     */
    public void setJndiName(String jndiName) throws NamingException {
        log.info("setJndiName() SnmpService : " + jndiName);
    	
        String oldName = this.jndiName;
        this.jndiName = jndiName;
        
        if (super.getState() == STARTED) {
        	try {
        		unbind(oldName);
        	} catch (NamingException e){
        		NamingException ne = new NamingException("Failed to unbind");
        		ne.setRootCause(e);
        		log.error(ne);
        	}

        	try{
        		rebind();
        	} catch (NamingException e){
        		NamingException ne = new NamingException("Failed to rebind");
        		ne.setRootCause(e);
        		log.error(ne);
        	}
        }
    }
	
    /**
     * @jmx.managed-attribute
     */
    public String getName() {
        return "PerformanceService(" + jndiName + ")";
    }
    
    /**
     * @jmx.managed-operation
     */
    public void restartCollector(){
    	manager.restartAll();
    }
	
    public void createService() {
        log.info("Create PerformanceService(" + jndiName + ")");
 
        manager = new PerformanceRestartManager();

        log.info("Created PerformanceService(" + jndiName + ")");
    }
    
    public void startService() throws NamingException {
        log.info("Start PerformanceService(" + jndiName + ")");
    	// ǽǽƤμƳ       
        manager.restartAll();
        
    	rebind();
        log.info("Started PerformanceService(" + jndiName + ")");
    }
    
    public void stopService() throws NamingException {
        log.info("Stop PerformanceService(" + jndiName + ")");
    	unbind(jndiName);
        
        // ơ֥ƺ
//        snmpSharedTable.deleteTableAll();
        
        log.info("Stoped PerformanceService(" + jndiName + ")");
    }
    
    public void destroyService() throws Exception {
        log.info("Destroy PerformanceService(" + jndiName + ")");
        
        manager = null;

        log.info("Destroyed PerformanceService(" + jndiName + ")");
    }
    
    private static Context createContext(Context rootCtx, Name name) throws NamingException {
    	Context subctx = rootCtx;
    	
    	for (int n = 0; n < name.size(); n++) {
    		String atom = name.get(n);
    		
    		try {
    			Object obj = subctx.lookup(atom);
    			subctx = (Context) obj;
    		} catch (NamingException e) {
    			// ¸ߤʤϡ֥ƥȤ
    			subctx = subctx.createSubcontext(atom);
    		}
    	}
    	
    	return subctx;
    }
    
    private void rebind() throws NamingException {
    	InitialContext rootCtx = new InitialContext();
    	
    	Name fullName = rootCtx.getNameParser("").parse(jndiName);
    	Name parentName = fullName;
    	if(fullName.size() > 1){
    		parentName = fullName.getPrefix(fullName.size()-1);
    	} else {
    		parentName = new CompositeName();
    	}
    	
    	Context parentCtx = createContext(rootCtx, parentName);
    	Name atomName = fullName.getSuffix(fullName.size()-1);
    	String atomStirng = atomName.get(0);
    	
    	NonSerializableFactory.rebind(parentCtx, atomStirng, manager);
    }
    
    private void unbind(String jndiName) throws NamingException {
    	InitialContext rootCtx = null;
    	
    	try {
    		rootCtx = new InitialContext();
    		
    		Name fullName = rootCtx.getNameParser("").parse(jndiName);
    		Name atomName = fullName.getSuffix(fullName.size() - 1);
    		String atom = atomName.get(0);
    		
    		rootCtx.unbind(jndiName);
    		NonSerializableFactory.unbind(atom);
    	} finally {
    		if(rootCtx != null) { 
    			rootCtx.close(); 
    		}
    	}
    }
}

==> hinemos-2.1.1_src.tar.gz: hinemos-2.1.1_src/PerformanceService/src/com/clustercontrol/performanceMGR/jmx/PerformanceService.java <==
/*
                                                                                                
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.
 
*/

package com.clustercontrol.performanceMGR.jmx;

import javax.naming.CompositeName;
import javax.naming.Context;
import javax.naming.InitialContext;
import javax.naming.Name;
import javax.naming.NamingException;

import org.jboss.naming.NonSerializableFactory;
import org.jboss.system.ServiceMBeanSupport;

/**
 * @jmx.mbean
 *     name="user:service=PerformanceService,name=PerformanceService"
 *     description="PerformanceService MBean"
 *     extends="org.jboss.system.ServiceMBean"
 * 
 * @jboss.service servicefile="snmppoller"
 */
public class PerformanceService extends ServiceMBeanSupport implements PerformanceServiceMBean{
	private String jndiName = "PerformanceService";  // JNDIに登録する際の名前
	
	private PerformanceRestartManager manager;
	
	public PerformanceService(){
	}
	
    /**
     * @jmx.managed-attribute
     * @return
     */
    public String getJndiName() {
        return jndiName;
    }
    
    /**
     * @jmx.managed-attribute
     * 
     * @param jndiName
     * @throws NamingException 
     * @throws NamingException
     */
    public void setJndiName(String jndiName) throws NamingException {
        log.info("setJndiName() SnmpService : " + jndiName);
    	
        String oldName = this.jndiName;
        this.jndiName = jndiName;
        
        if (super.getState() == STARTED) {
        	try {
        		unbind(oldName);
        	} catch (NamingException e){
        		NamingException ne = new NamingException("Failed to unbind");
        		ne.setRootCause(e);
        		log.error(ne);
        	}

        	try{
        		rebind();
        	} catch (NamingException e){
        		NamingException ne = new NamingException("Failed to rebind");
        		ne.setRootCause(e);
        		log.error(ne);
        	}
        }
    }
	
    /**
     * @jmx.managed-attribute
     */
    public String getName() {
        return "PerformanceService(" + jndiName + ")";
    }
    
    /**
     * @jmx.managed-operation
     */
    public void restartCollector(){
    	manager.restartAll();
    }
	
    public void createService() {
        log.info("Create PerformanceService(" + jndiName + ")");
 
        manager = new PerformanceRestartManager();

        log.info("Created PerformanceService(" + jndiName + ")");
    }
    
    public void startService() throws NamingException {
        log.info("Start PerformanceService(" + jndiName + ")");
    	// 性能管理機能の全ての収集を再開する       
        manager.restartAll();
        
    	rebind();
        log.info("Started PerformanceService(" + jndiName + ")");
    }
    
    public void stopService() throws NamingException {
        log.info("Stop PerformanceService(" + jndiName + ")");
    	unbind(jndiName);
        
        // テーブルを全て削除する
//        snmpSharedTable.deleteTableAll();
        
        log.info("Stoped PerformanceService(" + jndiName + ")");
    }
    
    public void destroyService() throws Exception {
        log.info("Destroy PerformanceService(" + jndiName + ")");
        
        manager = null;

        log.info("Destroyed PerformanceService(" + jndiName + ")");
    }
    
    private static Context createContext(Context rootCtx, Name name) throws NamingException {
    	Context subctx = rootCtx;
    	
    	for (int n = 0; n < name.size(); n++) {
    		String atom = name.get(n);
    		
    		try {
    			Object obj = subctx.lookup(atom);
    			subctx = (Context) obj;
    		} catch (NamingException e) {
    			// 存在しない場合は、サブコンテキストを生成
    			subctx = subctx.createSubcontext(atom);
    		}
    	}
    	
    	return subctx;
    }
    
    private void rebind() throws NamingException {
    	InitialContext rootCtx = new InitialContext();
    	
    	Name fullName = rootCtx.getNameParser("").parse(jndiName);
    	Name parentName = fullName;
    	if(fullName.size() > 1){
    		parentName = fullName.getPrefix(fullName.size()-1);
    	} else {
    		parentName = new CompositeName();
    	}
    	
    	Context parentCtx = createContext(rootCtx, parentName);
    	Name atomName = fullName.getSuffix(fullName.size()-1);
    	String atomStirng = atomName.get(0);
    	
    	NonSerializableFactory.rebind(parentCtx, atomStirng, manager);
    }
    
    private void unbind(String jndiName) throws NamingException {
    	InitialContext rootCtx = null;
    	
    	try {
    		rootCtx = new InitialContext();
    		
    		Name fullName = rootCtx.getNameParser("").parse(jndiName);
    		Name atomName = fullName.getSuffix(fullName.size() - 1);
    		String atom = atomName.get(0);
    		
    		rootCtx.unbind(jndiName);
    		NonSerializableFactory.unbind(atom);
    	} finally {
    		if(rootCtx != null) { 
    			rootCtx.close(); 
    		}
    	}
    }
}
